@@ -1,7 +1,6 @@
 #! /usr/local/bin/perl
 # Demo script for Lingua::EN::Fathom.pm
 
-use lib "../lib";
 
 use Lingua::EN::Fathom;
 
@@ -32,7 +31,7 @@ The second paragraph to analyse.
 
 #-------------------------------------------------------------------------------
 
-my $text = new Lingua::EN::Fathom;
+my $text = Lingua::EN::Fathom->new();
 $text->analyse_block($sample1,1);
 $text->analyse_block($sample2,1);
 
@@ -46,3 +45,5 @@ foreach $word ( sort keys  %uniq_words )
 }
 
 
+
+
